pub struct StandardSeedableRng { /* private fields */ }Expand description
An RNG that generates values directly from a seed (similar to proptest’s PassThrough RNG).
This is mostly only useful in conjunction with the provided distributions like
[StandardBuffered] because although the [RandCore] trait is restrictive and only allows
byte-level resolution, we want to do better than this.